==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/uk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Додати віддалений каталог {name} з {owner}@{remote}?",
    "Remote share" : "Віддалений каталог",
    "Remote share password" : "Пароль для віддаленого каталогу",
    "Cancel" : "Скасувати",
    "Add remote share" : "Додати віддалений каталог",
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "Server to server sharing is not enabled on this server" : "На даному сервері вимкнута можливість передачі даних між серверами",
    "Couldn't establish a federated share." : "Не вдалося встановити об’єднаний спільний доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не вдалося встановити федеративний спільний доступ, можливо, пароль неправильний.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запит на Federated Share надіслано, ви отримаєте запрошення. Перевірте сповіщення.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не вдалося встановити об’єднаний ресурс, схоже, сервер, з яким потрібно об’єднатися, застарий (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Заборонено надсилати об’єднані спільні групи з цього сервера.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Не вдалося надати спільний доступ %1$s, оскільки користувач %2$s уже має спільний доступ до цього елемента",
    "Not allowed to create a federated share with the same user" : "Заборонено створювати об’єднаний спільний ресурс з тим самим користувачем",
    "Federated shares require read permissions" : "Об’єднані спільні ресурси потребують дозволу на читання",
    "File is already shared with %s" : "Файл вже в загальному доступі з %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Помилка спільного доступу %1$s, не вдалося знайти %2$s, можливо, сервер наразі недоступний або використовує самопідписаний сертифікат.",
    "Could not find share" : "Не вдалося знайти спільний доступ",
    "Federated sharing" : "Об'єднаний спільний доступ",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Ви отримали \"%3$s\" як віддалений спільний доступ від %4$s (%1$s) (від імені %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Ви отримали {share} як віддалений спільний доступ від {user} (від імені {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Ви отримали \"%3$s\" як віддалений спільний доступ від %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Ви отримали {share} як віддалений спільний доступ від {user}",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Federated Cloud Sharing" : "Об’єднання хмарних сховищ",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID, див %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID",
    "Sharing" : "Поділитись",
    "Federated file sharing" : "Інтегрований обмін файлами",
    "Provide federated file sharing across servers" : "Забезпечте об’єднаний обмін файлами між серверами",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Налаштуйте, як люди можуть ділитися між серверами. Це також включає спільний доступ між користувачами на цьому сервері, якщо вони використовують федеративний спільний доступ.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволити користувачам на цьому сервері надсилати спільні файли на інші сервери (цей параметр також надає доступ WebDAV до публічних спільних ресурсів)",
    "Allow users on this server to receive shares from other servers" : "Дозволити користувачам на цьому сервері отримувати публікації з інших серверів",
    "Allow users on this server to send shares to groups on other servers" : "Дозволити користувачам цього сервера надсилати спільні файли групам на інших серверах",
    "Allow users on this server to receive group shares from other servers" : "Дозволити користувачам на цьому сервері отримувати групові спільні файли з інших серверів",
    "Search global and public address book for users" : "Пошук по глобальній та публічній адресній книзі для користувачів",
    "Allow users to publish their data to a global and public address book" : "Дозволити користувачам публікувати свої дані в глобальній загальнодоступній адресній книзі",
    "Unable to update federated files sharing config" : "Неможливо оновити конфігурацію спільного доступу до об’єднаних файлів",
    "Federated Cloud" : "Федеративна хмара",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Ви можете поділитися з будь-ким, хто використовує сервер Nextcloud або інші сервери та служби, сумісні з Open Cloud Mesh (OCM). Просто введіть їхній Federated Cloud ID у діалоговому вікні спільного доступу. Це виглядає як person@cloud.example.com",
    "Your Federated Cloud ID:" : "Ваш ідентифікатор Federated Cloud:",
    "Share it so your friends can share files with you:" : "Поділіться ним, щоб ваші друзі могли ділитися з вами файлами:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Діаспора",
    "Add to your website" : "Додати на ваш вебсайт",
    "Share with me via Nextcloud" : "Поділися зі мною через Nextcloud",
    "HTML Code:" : "HTML код:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID, див. {url}",
    "Cloud ID copied to the clipboard" : "Cloud ID скопійовано в буфер обміну",
    "Copy to clipboard" : "Скопіювати в буфер обміну ",
    "Clipboard is not available" : "Буфер обміну недоступний",
    "Copy" : "Копіювати",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C для копіювання.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C для копіювання.",
    "Open documentation" : "Відкрити документацію",
    "Adjust how people can share between servers." : "Налаштуйте, як люди можуть ділитися між серверами."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/uk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Додати віддалений каталог {name} з {owner}@{remote}?",
    "Remote share" : "Віддалений каталог",
    "Remote share password" : "Пароль для віддаленого каталогу",
    "Cancel" : "Скасувати",
    "Add remote share" : "Додати віддалений каталог",
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "Server to server sharing is not enabled on this server" : "На даному сервері вимкнута можливість передачі даних між серверами",
    "Couldn't establish a federated share." : "Не вдалося встановити об’єднаний спільний доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не вдалося встановити федеративний спільний доступ, можливо, пароль неправильний.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запит на Federated Share надіслано, ви отримаєте запрошення. Перевірте сповіщення.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не вдалося встановити об’єднаний ресурс, схоже, сервер, з яким потрібно об’єднатися, застарий (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Заборонено надсилати об’єднані спільні групи з цього сервера.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Не вдалося надати спільний доступ %1$s, оскільки користувач %2$s уже має спільний доступ до цього елемента",
    "Not allowed to create a federated share with the same user" : "Заборонено створювати об’єднаний спільний ресурс з тим самим користувачем",
    "Federated shares require read permissions" : "Об’єднані спільні ресурси потребують дозволу на читання",
    "File is already shared with %s" : "Файл вже в загальному доступі з %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Помилка спільного доступу %1$s, не вдалося знайти %2$s, можливо, сервер наразі недоступний або використовує самопідписаний сертифікат.",
    "Could not find share" : "Не вдалося знайти спільний доступ",
    "Federated sharing" : "Об'єднаний спільний доступ",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Ви отримали \"%3$s\" як віддалений спільний доступ від %4$s (%1$s) (від імені %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Ви отримали {share} як віддалений спільний доступ від {user} (від імені {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Ви отримали \"%3$s\" як віддалений спільний доступ від %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Ви отримали {share} як віддалений спільний доступ від {user}",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Federated Cloud Sharing" : "Об’єднання хмарних сховищ",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID, див %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID",
    "Sharing" : "Поділитися",
    "Federated file sharing" : "Інтегрований обмін файлами",
    "Provide federated file sharing across servers" : "Забезпечте об’єднаний обмін файлами між серверами",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Налаштуйте, як люди можуть ділитися між серверами. Це також включає спільний доступ між користувачами на цьому сервері, якщо вони використовують федеративний спільний доступ.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволити користувачам на цьому сервері надсилати спільні файли на інші сервери (цей параметр також надає доступ WebDAV до публічних спільних ресурсів)",
    "Allow users on this server to receive shares from other servers" : "Дозволити користувачам на цьому сервері отримувати публікації з інших серверів",
    "Allow users on this server to send shares to groups on other servers" : "Дозволити користувачам цього сервера надсилати спільні файли групам на інших серверах",
    "Allow users on this server to receive group shares from other servers" : "Дозволити користувачам на цьому сервері отримувати групові спільні файли з інших серверів",
    "Search global and public address book for users" : "Пошук по глобальній та публічній адресній книзі для користувачів",
    "Allow users to publish their data to a global and public address book" : "Дозволити користувачам публікувати свої дані в глобальній загальнодоступній адресній книзі",
    "Unable to update federated files sharing config" : "Неможливо оновити конфігурацію спільного доступу до об’єднаних файлів",
    "Federated Cloud" : "Федеративна хмара",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Ви можете поділитися з будь-ким, хто використовує сервер Nextcloud або інші сервери та служби, сумісні з Open Cloud Mesh (OCM). Просто введіть їхній Federated Cloud ID у діалоговому вікні спільного доступу. Це виглядає як person@cloud.example.com",
    "Your Federated Cloud ID:" : "Ваш ідентифікатор Federated Cloud:",
    "Share it so your friends can share files with you:" : "Поділіться ним, щоб ваші друзі могли ділитися з вами файлами:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Діаспора",
    "Add to your website" : "Додати на ваш вебсайт",
    "Share with me via Nextcloud" : "Поділися зі мною через Nextcloud",
    "HTML Code:" : "Код HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID, див. {url}",
    "Cloud ID copied to the clipboard" : "Cloud ID скопійовано в буфер обміну",
    "Copy to clipboard" : "Скопіювати в буфер обміну ",
    "Clipboard is not available" : "Буфер обміну недоступний",
    "Copy" : "Копіювати",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C для копіювання.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C для копіювання.",
    "Open documentation" : "Відкрити документацію",
    "Adjust how people can share between servers." : "Налаштуйте, як люди можуть ділитися між серверами."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
